/*$Id: c_insert.cc,v 17.1 2000/02/19 08:51:13 al Exp $ -*- C++ -*-
 * insert command
 * insert new nodes
 * Doesn't really work.
 * Appears to insert into net list, but does not update anything else.
 * It may go away.
 */
#include "e_card.h"
#include "u_status.h"
#include "ap.h"
#include "s__.h"
#include "c_comand.h"
/*--------------------------------------------------------------------------*/
//	void	CMD::insert(CS&);
/*--------------------------------------------------------------------------*/
void CMD::insert(CS& cmd)
{
  int nod;		/* first node number to insert */
  int ncnt;		/* how many nodes to insert */
  
  SIM::uninit();
  nod = cmd.ctoi();
  if (nod <= 0)
    error(bERROR, "insert which node?\n");
  if (nod > STATUS::total_nodes)
    error(bERROR, "%u nodes\n", STATUS::total_nodes);
  
  ncnt = cmd.ctoi();
  if (ncnt <= 0)
    ncnt = 1;
  
  untested();
  for (CARD_LIST::iterator 
	 ci=CARD_LIST::card_list.begin();ci!=CARD_LIST::card_list.end();++ci){
    CARD* brh = *ci;
    if (brh->is_device()){
      for (int ii = 0;  brh->_n[ii].e != INVALIDNODE;  ii++){
	if (brh->_n[ii].e >= nod)		/* move them up */
	  brh->_n[ii].e += ncnt;
      }
    }
  untested();
  }
}
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
